==> weblog-1_41.tar.gz: weblog/language/japanese/modinfo.php <==
<?php
/**
 * $Id: modinfo.php,v 1.9 2005/04/13 06:18:31 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 *
 * version j0.91 2003/05/19 JST
 */

define('_MI_WEBLOG_NAME','֥');
define('_MI_WEBLOG_DESC','֥/㡼ʥ륷ƥ');
define('_MI_WEBLOG_SMNAME1','ޥ֥');
define('_MI_WEBLOG_SMNAME2','֥');
define('_MI_WEBLOG_SMNAME3','');

// submenu name
define('_MI_WEBLOG_DBMANAGER', 'ǡ١');
define('_MI_WEBLOG_CATMANAGER', 'ƥ');
define('_MI_WEBLOG_PRIVMANAGER', '´');
define('_MI_WEBLOG_MYBLOCKSADMIN', '֥å');

define('_MI_WEBLOG_NOTIFY','ɽΥ֥');
define('_MI_WEBLOG_NOTIFYDSC','Υ֥ѹäΤ');
define('_MI_WEBLOG_ENTRY_NOTIFY','ɽΥ֥ȥ');
define('_MI_WEBLOG_ENTRY_NOTIFYDSC','Υ֥ȥѹäΤ');

define('_MI_WEBLOG_ADD_NOTIFY','');
define('_MI_WEBLOG_ADD_NOTIFYCAP','ȥ꤬Ƥ줿Τ');
define('_MI_WEBLOG_ADD_NOTIFYDSC','ȥ꤬Ƥ줿Ȥ');
define('_MI_WEBLOG_ADD_NOTIFYSBJ','֥');

define('_MI_WEBLOG_ENTRY_COMMENT','ɲä줿');
define('_MI_WEBLOG_ENTRY_COMMENTDSC','Υȥ˿ȤƤ줿Τ');

define('_MI_WEBLOG_RECENT_BNAME1','ǿ֥ȥ');
define('_MI_WEBLOG_RECENT_BNAME1_DESC','ǿ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS','ȥåץ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS_DESC','äȤɤޤƤ֥ȥ');
define('_MI_WEBLOG_USERS_WEBLOGS','Ƽ̥ȥ');
define('_MI_WEBLOG_USERS_WEBLOGS_DESC','桼κǿ֥ȥ');
define('_MI_WEBLOG_RECENT_TRACKBACKS','ǶΥȥåХå');
define('_MI_WEBLOG_RECENT_TRACKBACKS_DESC','ǶȥåХå');
define('_MI_WEBLOG_RECENT_COMMENTS','ǶweBLogΥ');
define('_MI_WEBLOG_RECENT_COMMENTS_DESC','weBLogΥȥ˺Ƕդ줿');
define('_MI_WEBLOG_LINKS','weBLogƼѥ');
define('_MI_WEBLOG_LINKS_DESC','󥯥⥸塼Υ󥯥ꥹ');
define('_MI_WEBLOG_RECENT_IMAGES','ǶΥ᡼');
define('_MI_WEBLOG_RECENT_IMAGES_DESC','weBLogǺǶȤ줿᡼');

// Config Settings
define('_MI_WEBLOG_NUMPERPAGE','ڡɽ륨ȥ');
define('_MI_WEBLOG_NUMPERPAGEDSC','');
define('_MI_WEBLOG_DATEFORMAT','ս');
define('_MI_WEBLOG_DATEFORMATDSC','');
define('_MI_WEBLOG_TIMEFORMAT','');
define('_MI_WEBLOG_TIMEFORMATDSC','');
define('_MI_WEBLOG_RECENT_DATEFORMAT','ǿȥ֥åս');
define('_MI_WEBLOG_RECENT_DATEFORMATDSC','');
define('_MI_WEBLOG_SHOWAVATAR','ƥȥ˥Хɽ');
define('_MI_WEBLOG_SHOWAVATARDSC','');
define('_MI_WEBLOG_ALIGNAVATAR','Х');
define('_MI_WEBLOG_ALIGNAVATARDSC','');
define('_MI_WEBLOG_MINENTRYSIZE','ȥκ㥵');
define('_MI_WEBLOG_MINENTRYSIZEDSC','0ꤹȥåޤ');
define('_MI_WEBLOG_IMGURL', 'URL');
define('_MI_WEBLOG_IMGURLDSC', 'ѥڡRSSɽޤϵҤURLꤷޤ');
define('_MI_WEBLOG_OPDOHTML', 'ץ/HTML̵') ;
define('_MI_WEBLOG_OPDOHTMLDSC', 'HTML̵פΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
define('_MI_WEBLOG_OPPRIVATE', 'ץ/ץ饤١') ;
define('_MI_WEBLOG_OPPRIVATEDSC', '֥ץ饤١ȡפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
define('_MI_WEBLOG_OPUPDATEPING', 'ץ/Ping') ;
define('_MI_WEBLOG_OPUPDATEPINGDSC', 'ֹPingפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;

define('_MI_WEBLOG_UPDATE_READS_WHEN','򥫥ȥåפΤ');
define('_MI_WEBLOG_UPDATE_READS_WHENDSC','־ܺ٤줿ȤפǤϾܺٲ̤ǥȥȤ֥桼ΥꥹȤ줿ȤפǤϤ桼ΥȥꥹȥåפȤ֥ꥹȤ줿ȤפǤϤɤʷǤ쥨ȥ꤬ꥹȥåפ줿Ȥ줾ޤ');
define('_MI_WEBLOG_UPDATE_READS_WHEN1','ܺ٤줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN2','桼ΥꥹȤ줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN3','ꥹȤ줿Ȥ');

define('_MI_WEBLOG_TEMPLATE_ENTRIESDSC','ꤵ줿֥Υȥɽ');
define('_MI_WEBLOG_TEMPLATE_POSTDSC','֥ȥƤ');
define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','֥ȥξܺ٤ɽ');
define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','ǿȥRSSե');
define('_MI_WEBLOG_TEMPLATE_PRINTDSC','ѥڡ');
define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','ȤΥ֥ꥹ');
define('_MI_WEBLOG_TEMPLATE_IMAGEMANAGERDSC','֥ѤΥ᡼ޥ͡');

define('_MI_WEBLOG_EDITORHEIGHT','Խѥƥȥꥢι⤵()');
define('_MI_WEBLOG_EDITORHEIGHTDSC','Խѥƥȥꥢι⤵Կꤷޤ');
define('_MI_WEBLOG_EDITORWIDTH','Խѥƥȥꥢ(ʸ)');
define('_MI_WEBLOG_EDITORWIDTHDSC','Խѥƥȥꥢꤷޤ');
define('_MI_WEBLOG_ONLYADMIN',"ͥ롼ץ桼ΤߤƤǤ");
define('_MI_WEBLOG_ONLYADMINDSC','֤פꤹȤ٤ƤϿ桼ȥƤ뤳ȤǤޤĤޤ֤Ϥפꤹȴͥ롼פΥ桼ƤǤޤ');

// wellwine for read cookie
define('_MI_WEBLOG_EXPIRATION','Ѥߤͭ(ñ:)');
define('_MI_WEBLOG_EXPIRATIONDSC','֥ȥꤴȤαѤͭ¤ꤷƤδ֤᤮Ʊȥȱޤ');
define('_MI_WEBLOG_RSSSHOW','RSSɽ');
define('_MI_WEBLOG_RSSSHOWDSC','');
define('_MI_WEBLOG_RSSMAX','RSS˥եɤ륨ȥ');
define('_MI_WEBLOG_RSSMAXDSC','');

define('_MI_WEBLOG_USESEPARATOR','ȥȾʬǽλ');
define('_MI_WEBLOG_USESEPARATORDSC','ڤʸ뤳ȤǡȥȾȸȾʬ뤳ȤǤޤˤȾʬΤߤɽ졢ܺ٥ڡˤϥȥɽޤ');
define('_MI_WEBLOG_USESMEMBERONLY','Ͽ桼Τ߱ǽʬλ');
define('_MI_WEBLOG_USESMEMBERONLYDSC','ڤʸ뤳ȤǡȥΤʹߤʬϿ桼Τߤɤ褦ˤʤޤ');
define('_MI_WEBLOG_USEIMAGEMANAGER','֥ѥ᡼ޥ͡λ');
define('_MI_WEBLOG_USEIMAGEMANAGERDSC','ɸΥ᡼ޥ͡Ȥ̤ˡͥɽʤƻ˲ޤ');


// myalbum-P image manager
// Config Items
define( "_MI_ALBM_CFG_PHOTOSPATH" , "ե¸ǥ쥯ȥ" ) ;
define( "_MI_ALBM_CFG_DESCPHOTOSPATH" , "XOOPS󥹥ȡ褫Υѥʺǽ'/'ɬסǸ'/'ס<br />UnixǤϤΥǥ쥯ȥؤν°ONˤƲ" ) ;
define( "_MI_ALBM_CFG_THUMBSPATH" , "ͥե¸ǥ쥯ȥ" ) ;
define( "_MI_ALBM_CFG_DESCTHUMBSPATH" , "ֲե¸ǥ쥯ȥפƱǤ" ) ;
//define( "_MI_ALBM_CFG_THUMBWIDTH" , "ͥ" ) ;
//define( "_MI_ALBM_CFG_DESCTHUMBWIDTH" , "륵ͥι⤵ϡ鼫ư׻ޤ" ) ;
define( "_MI_ALBM_CFG_THUMBSIZE" , "ͥ(pixel)" ) ;
define( "_MI_ALBM_CFG_THUMBRULE" , "ͥˡ§" ) ;
define( "_MI_ALBM_CFG_WIDTH" , "" ) ;
define( "_MI_ALBM_CFG_DESCWIDTH" , "åץɻ˼ưĴᥤκ<br />GD⡼ɤTrueColor򰷤ʤˤñʤ륵" ) ;
define( "_MI_ALBM_CFG_HEIGHT" , "" ) ;
define( "_MI_ALBM_CFG_DESCHEIGHT" , "Ʊ̣Ǥ" ) ;
define( "_MI_ALBM_CFG_FSIZE" , "ե륵" ) ;
define( "_MI_ALBM_CFG_DESCFSIZE" , "åץɻΥե륵(byte)" ) ;
define( "_MI_ALBM_CFG_MIDDLEPIXEL" , "󥰥ӥ塼Ǥκ" ) ;
define( "_MI_ALBM_CFG_DESCMIDDLEPIXEL" , "x⤵ ǻꤷޤ<br /> 480x480" ) ;

define( "_MI_ALBUM_OPT_CALCFROMWIDTH" , "ͤȤơ⤵ư׻" ) ;
define( "_MI_ALBUM_OPT_CALCFROMHEIGHT" , "ͤ⤵Ȥơư׻" ) ;
define( "_MI_ALBUM_OPT_CALCWHINSIDEBOX" , "⤵礭ͤˤʤ褦ư׻" ) ;

?>

==> weblog-1_42.tar.gz: weblog/language/japanese/modinfo.php <==
<?php
/**
 * $Id: modinfo.php,v 1.16 2005/08/14 06:15:44 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 *
 * version j0.91 2003/05/19 JST
 */
if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'WEBLOG_MI_LOADED' ) ) {

define( 'WEBLOG_MI_LOADED' , 1 ) ;

define('_MI_WEBLOG_NAME','֥');
define('_MI_WEBLOG_DESC','֥/㡼ʥ륷ƥ');
define('_MI_WEBLOG_SMNAME1','ޥ֥');
define('_MI_WEBLOG_SMNAME2','֥');
define('_MI_WEBLOG_SMNAME3','');

// submenu name
define('_MI_WEBLOG_DBMANAGER', 'ǡ١');
define('_MI_WEBLOG_CATMANAGER', 'ƥ');
define('_MI_WEBLOG_PRIVMANAGER', '´(weBLog simple)');
define('_MI_WEBLOG_MYGROUPSADMIN', '´(XOOPS standard)');
define('_MI_WEBLOG_MYBLOCKSADMIN', '֥å');
define('_MI_WEBLOG_TEMPLATE_MANEGER', 'ƥץ졼ȡޥ͡');

define('_MI_WEBLOG_NOTIFY','ɽΥ֥');
define('_MI_WEBLOG_NOTIFYDSC','Υ֥ѹäΤ');
define('_MI_WEBLOG_ENTRY_NOTIFY','ɽΥ֥ȥ');
define('_MI_WEBLOG_ENTRY_NOTIFYDSC','Υ֥ȥѹäΤ');

define('_MI_WEBLOG_ADD_NOTIFY','');
define('_MI_WEBLOG_ADD_NOTIFYCAP','ȥ꤬Ƥ줿Τ');
define('_MI_WEBLOG_ADD_NOTIFYDSC','ȥ꤬Ƥ줿Ȥ');
define('_MI_WEBLOG_ADD_NOTIFYSBJ','֥');

define('_MI_WEBLOG_ENTRY_COMMENT','ɲä줿');
define('_MI_WEBLOG_ENTRY_COMMENTDSC','Υȥ˿ȤƤ줿Τ');

define('_MI_WEBLOG_RECENT_BNAME1','ǿ֥ȥ');
define('_MI_WEBLOG_RECENT_BNAME1_DESC','ǿ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS','ȥåץ֥ȥ');
define('_MI_WEBLOG_TOP_WEBLOGS_DESC','äȤɤޤƤ֥ȥ');
define('_MI_WEBLOG_USERS_WEBLOGS','Ƽ̥ȥ');
define('_MI_WEBLOG_USERS_WEBLOGS_DESC','桼κǿ֥ȥ');
define('_MI_WEBLOG_RECENT_TRACKBACKS','ǶΥȥåХå');
define('_MI_WEBLOG_RECENT_TRACKBACKS_DESC','ǶȥåХå');
define('_MI_WEBLOG_RECENT_COMMENTS','ǶweBLogΥ');
define('_MI_WEBLOG_RECENT_COMMENTS_DESC','weBLogΥȥ˺Ƕդ줿');
define('_MI_WEBLOG_LINKS','weBLogƼѥ');
define('_MI_WEBLOG_LINKS_DESC','󥯥⥸塼Υ󥯥ꥹ');
define('_MI_WEBLOG_RECENT_IMAGES','ǶΥ᡼');
define('_MI_WEBLOG_RECENT_IMAGES_DESC','weBLogǺǶȤ줿᡼');
define('_MI_WEBLOG_CATEGORY_LIST', 'ƥ');
define('_MI_WEBLOG_CATEGORY_LIST_DESC', 'Ĥƥ');
define('_MI_WEBLOG_TB_CENTER', 'ȥåХå󥿡');
define('_MI_WEBLOG_TB_CENTERDSC', 'ȥåХåä˽᤿ȥΰ');
// hodaka added archive list block
define('_MI_WEBLOG_ARCHIVE_LIST', '');
define('_MI_WEBLOG_ARCHIVE_LIST_DESC', '¤ؤǽʥ');
// hodaka added calendar block
define('_MI_WEBLOG_CALENDAR', '֥ ');
define('_MI_WEBLOG_CALENDAR_DESC', '');

// Config Settings
define('_MI_WEBLOG_NUMPERPAGE','ڡɽ륨ȥ');
define('_MI_WEBLOG_NUMPERPAGEDSC','');
define('_MI_WEBLOG_DATEFORMAT','ս');
define('_MI_WEBLOG_DATEFORMATDSC','');
define('_MI_WEBLOG_TIMEFORMAT','');
define('_MI_WEBLOG_TIMEFORMATDSC','');
define('_MI_WEBLOG_RECENT_DATEFORMAT','ǿȥ֥åս');
define('_MI_WEBLOG_RECENT_DATEFORMATDSC','');
define('_MI_WEBLOG_SHOWAVATAR','ƥȥ˥Хɽ');
define('_MI_WEBLOG_SHOWAVATARDSC','');
define('_MI_WEBLOG_ALIGNAVATAR','Х');
define('_MI_WEBLOG_ALIGNAVATARDSC','');
define('_MI_WEBLOG_MINENTRYSIZE','ȥκ㥵');
define('_MI_WEBLOG_MINENTRYSIZEDSC','0ꤹȥåޤ');
define('_MI_WEBLOG_IMGURL', 'URL');
define('_MI_WEBLOG_IMGURLDSC', 'ѥڡRSSɽޤϵҤURLꤷޤ');
define('_MI_WEBLOG_OPDOHTML', 'ץ/HTML̵') ;
define('_MI_WEBLOG_OPDOHTMLDSC', 'HTML̵פΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
define('_MI_WEBLOG_OPDOBR', 'ץ/Ԥư') ;
define('_MI_WEBLOG_OPDOBRDSC', 'ֲԤưפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
define('_MI_WEBLOG_OPPRIVATE', 'ץ/ץ饤١') ;
define('_MI_WEBLOG_OPPRIVATEDSC', '֥ץ饤١ȡפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
define('_MI_WEBLOG_OPUPDATEPING', 'ץ/Ping') ;
define('_MI_WEBLOG_OPUPDATEPINGDSC', 'ֹPingפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;

define('_MI_WEBLOG_UPDATE_READS_WHEN','򥫥ȥåפΤ');
define('_MI_WEBLOG_UPDATE_READS_WHENDSC','־ܺ٤줿ȤפǤϾܺٲ̤ǥȥȤ֥桼ΥꥹȤ줿ȤפǤϤ桼ΥȥꥹȥåפȤ֥ꥹȤ줿ȤפǤϤɤʷǤ쥨ȥ꤬ꥹȥåפ줿Ȥ줾ޤ');
define('_MI_WEBLOG_UPDATE_READS_WHEN1','ܺ٤줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN2','桼ΥꥹȤ줿Ȥ');
define('_MI_WEBLOG_UPDATE_READS_WHEN3','ꥹȤ줿Ȥ');
define('_MI_WEBLOG_GTICKETTIMEOUT','Ƥ»');
define('_MI_WEBLOG_GTICKETTIMEOUTDSC','ƥڡ򳫤Ƥ顢ʬƤʤȥॢȽޤ');

define('_MI_WEBLOG_TEMPLATE_ENTRIESDSC','ꤵ줿֥Υȥɽ');
define('_MI_WEBLOG_TEMPLATE_POSTDSC','֥ȥƤ');
define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','֥ȥξܺ٤ɽ');
define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','ǿȥRSSե');
define('_MI_WEBLOG_TEMPLATE_PRINTDSC','ѥڡ');
define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','ȤΥ֥ꥹ');
define('_MI_WEBLOG_TEMPLATE_IMAGEMANAGERDSC','֥ѤΥ᡼ޥ͡');
define('_MI_WEBLOG_CALBLOCKCSS_DSC','֥åѤΥ륷');
// myarchive.php by hodaka
define('_MI_WEBLOG_TEMPLATE_MYARCHIVEDSC', '¤ؤѥ֥ꥹ');

define('_MI_WEBLOG_EDITORHEIGHT','Խѥƥȥꥢι⤵()');
define('_MI_WEBLOG_EDITORHEIGHTDSC','Խѥƥȥꥢι⤵Կꤷޤ');
define('_MI_WEBLOG_EDITORWIDTH','Խѥƥȥꥢ(ʸ)');
define('_MI_WEBLOG_EDITORWIDTHDSC','Խѥƥȥꥢꤷޤ');
define('_MI_WEBLOG_ONLYADMIN',"ͥ롼ץ桼ΤߤƤǤ");
define('_MI_WEBLOG_ONLYADMINDSC','֤פꤹȤ٤ƤϿ桼ȥƤ뤳ȤǤޤĤޤ֤Ϥפꤹȴͥ롼פΥ桼ƤǤޤ(ϸ´ˡ"weBLog"ȤͭǤ)');
define('_MI_WEBLOG_POST_COUNTUP',"Ƥ桼ƿȿ");
define('_MI_WEBLOG_POST_COUNTUPDSC','ȥƤXOOPS桼ƿȤƥȤ뤫ɤǤ');
define('_MI_WEBLOG_DISABLE_HTML',"HTMLŪ˻ԲĤˤޤ");
define('_MI_WEBLOG_DISABLE_HTMLDSC','Ǥʤ桼ϿǤȥƤǤ硢ƥ֤ϤפˤƤ');
define('_MI_WEBLOG_TB_BLOGNAME',"ȥåХåˡ֥֥̾פȤƻȤʸ");
define('_MI_WEBLOG_TB_BLOGNAMEDSC','{MODULE_NAME}⥸塼̾{USER_NAME}桼̾{SITE_NAME}򥵥̾ȤƻȤޤ');

// wellwine for read cookie
define('_MI_WEBLOG_EXPIRATION','Ѥߤͭ(ñ:)');
define('_MI_WEBLOG_EXPIRATIONDSC','֥ȥꤴȤαѤͭ¤ꤷƤδ֤᤮Ʊȥȱޤ');
define('_MI_WEBLOG_RSSSHOW','RSSɽ');
define('_MI_WEBLOG_RSSSHOWDSC','');
define('_MI_WEBLOG_RSSMAX','RSS˥եɤ륨ȥ');
define('_MI_WEBLOG_RSSMAXDSC','');

define('_MI_WEBLOG_USESEPARATOR','ȥȾʬǽλ');
define('_MI_WEBLOG_USESEPARATORDSC','ڤʸ뤳ȤǡȥȾȸȾʬ뤳ȤǤޤˤȾʬΤߤɽ졢ܺ٥ڡˤϥȥɽޤ');
define('_MI_WEBLOG_USESMEMBERONLY','Ͽ桼Τ߱ǽʬλ');
define('_MI_WEBLOG_USESMEMBERONLYDSC','ڤʸ뤳ȤǡȥΤʹߤʬϿ桼Τߤɤ褦ˤʤޤ');
define('_MI_WEBLOG_USEIMAGEMANAGER','֥ѥ᡼ޥ͡λ');
define('_MI_WEBLOG_USEIMAGEMANAGERDSC','ɸΥ᡼ޥ͡Ȥ̤ˡͥɽʤƻ˲ޤ');
define('_MI_WEBLOG_USEPERMITSYSTEM','ƥȥꤴȤΥѡߥ굡ǽλ');
define('_MI_WEBLOG_USEPERMITSYSTEMDSC','εǽϡȥƻˤɤΥ롼פ˱¤Ϳ뤫꤬Ǥޤ');
define('_MI_WEBLOG_DEFAULT_PERMIT','ѡߥåͭˤƤΥǥե');
define('_MI_WEBLOG_DEFAULT_PERMITDSC','ƻ˥ǥեȤФƤѡߥǤ');
define('_MI_WEBLOG_PERMIT_SHOWTITLE','¤ʤ桼ˤ⥿ȥɽ') ;
define('_MI_WEBLOG_PERMIT_SHOWTITLEDSC','ȥΤɽ뤳Ȥǡɤʥȥ꤬뤫Ť뤳ȤǤޤεǽONˤ硢桼϶ػߤƤ륨ȥΥȥåХåȥȤɤळȤǤ褦ˤʤޤ') ;
//define('_MI_WEBLOG_PERMIT_INGROUP' , 'Ʊ롼ספ');
//define('_MI_WEBLOG_PERMIT_INGROUPDSC' , '');
//define('_MI_WEBLOG_PERMIT_OUTGROUP' , 'ְۤʤ륰롼ספ');
//define('_MI_WEBLOG_PERMIT_OUTGROUPDSC' , '');
//define('_MI_WEBLOG_PERMIT_G_COMPLETE_S','Ƥν°롼פ˰סʴס');
//define('_MI_WEBLOG_PERMIT_G_PARTIAL_S','1ĤǤ°롼פסʬס');
//define('_MI_WEBLOG_PERMIT_G_COMPLETE_D','°륰롼פǰפΤ̵ʴ¾');
//define('_MI_WEBLOG_PERMIT_G_PARTIAL_D','1ĤǤ°롼פۤʤäƤʬ¾');
define('_MI_WEBLOG_PRIVILEGE_SYSTEM','֥⥸塼θ´ˡ');
define('_MI_WEBLOG_PRIVILEGE_SYSTEMDSC','С1.41ޤǤΤ֥ȼΥץʸ´ˡȡXOOPSɸθ´ˡΤɤȤ٤ޤ');
define('_MI_WEBLOG_SHOWCATEGORY','ƥɽ');
define('_MI_WEBLOG_SHOWCATEGORY_DSC','index.phpǥƥ򸫤ϡ"Ϥ"ˤƤ');
define('_MI_WEBLOG_CAT_POSTPERM','ƻΥƥµǽ');
define('_MI_WEBLOG_CAT_POSTPERM_DSC','ͭˤ硢桼ƤǤ륫ƥ򥰥롼Ǥޤ');
define('_MI_WEBLOG_CAT_LISTCOL','ƥʿ');
define('_MI_WEBLOG_CAT_LISTCOL_DSC','ƥɽ硢1˲ɽ뤫');

// myalbum-P image manager
// Config Items
define( "_MI_ALBM_CFG_PHOTOSPATH" , "ե¸ǥ쥯ȥ" ) ;
define( "_MI_ALBM_CFG_DESCPHOTOSPATH" , "XOOPS󥹥ȡ褫Υѥʺǽ'/'ɬסǸ'/'ס<br />UnixǤϤΥǥ쥯ȥؤν°ONˤƲ" ) ;
define( "_MI_ALBM_CFG_THUMBSPATH" , "ͥե¸ǥ쥯ȥ" ) ;
define( "_MI_ALBM_CFG_DESCTHUMBSPATH" , "ֲե¸ǥ쥯ȥפƱǤ" ) ;
//define( "_MI_ALBM_CFG_THUMBWIDTH" , "ͥ" ) ;
//define( "_MI_ALBM_CFG_DESCTHUMBWIDTH" , "륵ͥι⤵ϡ鼫ư׻ޤ" ) ;
define( "_MI_ALBM_CFG_THUMBSIZE" , "ͥ(pixel)" ) ;
define( "_MI_ALBM_CFG_THUMBRULE" , "ͥˡ§" ) ;
define( "_MI_ALBM_CFG_WIDTH" , "" ) ;
define( "_MI_ALBM_CFG_DESCWIDTH" , "åץɻ˼ưĴᥤκ<br />GD⡼ɤTrueColor򰷤ʤˤñʤ륵" ) ;
define( "_MI_ALBM_CFG_HEIGHT" , "" ) ;
define( "_MI_ALBM_CFG_DESCHEIGHT" , "Ʊ̣Ǥ" ) ;
define( "_MI_ALBM_CFG_FSIZE" , "ե륵" ) ;
define( "_MI_ALBM_CFG_DESCFSIZE" , "åץɻΥե륵(byte)" ) ;
define( "_MI_ALBM_CFG_MIDDLEPIXEL" , "󥰥ӥ塼Ǥκ" ) ;
//define( "_MI_ALBM_CFG_DESCMIDDLEPIXEL" , "x⤵ ǻꤷޤ<br /> 480x480" ) ;

define( "_MI_ALBUM_OPT_CALCFROMWIDTH" , "ͤȤơ⤵ư׻" ) ;
define( "_MI_ALBUM_OPT_CALCFROMHEIGHT" , "ͤ⤵Ȥơư׻" ) ;
define( "_MI_ALBUM_OPT_CALCWHINSIDEBOX" , "⤵礭ͤˤʤ褦ư׻" ) ;


}
?>
